# Copyright The OpenTelemetry Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import Final

ONC_RPC_PROCEDURE_NAME: Final = "onc_rpc.procedure.name"
"""
ONC/Sun RPC procedure name.
"""

ONC_RPC_PROCEDURE_NUMBER: Final = "onc_rpc.procedure.number"
"""
ONC/Sun RPC procedure number.
"""

ONC_RPC_PROGRAM_NAME: Final = "onc_rpc.program.name"
"""
ONC/Sun RPC program name.
"""

ONC_RPC_VERSION: Final = "onc_rpc.version"
"""
ONC/Sun RPC program version.
"""
